#!/bin/sh
set -e
set -x
# Heavily inspired by <https://docs-develop.pleroma.social/backend/installation/debian_based_en/>

if [ "$#" -ne 3 ]; then
    echo 'Need domain name and mail and old server IP as argument.'
    false
fi
domain="$1"
mail="$2"
old_server="$3"

# Install configs, set up firewall.
config_tree_prefix="${HOME}/config/buster"
./install_for_target.sh web website
./copy_dirtree.sh "${config_tree_prefix}/etc_files" "" web website
nft -f /etc/nftables.conf

# Set up letsencrypt certificate. TODO: Is it auto-renewed?
ln -sf /etc/nginx/sites-available/default /etc/nginx/sites-enabled/default
certbot --nginx --agree-tos --redirect --no-eff-email -m "${mail}" -d "${domain}"
rm /etc/nginx/sites-enabled/default

# Set up repos dir.
mkdir /var/repos
chown plom:plom /var/repos
# To use this dir, "git clone --mirror" repo source paths into it as user plom.
# As user plom, touch git-daemon-export-ok files into it to make the repo
# publically available.

# Prepare NGINX and GitWeb config.
sed -i "s/REPLACE_fqdn_ECALPER/${domain}/g" /etc/gitweb.conf
sed -i "s/REPLACE_fqdn_ECALPER/${domain}/g" /etc/nginx/sites-available/website.nginx
ln -s /etc/nginx/sites-available/website.nginx /etc/nginx/sites-enabled/website.nginx

# Set up website.
rm -rf /var/www
mkdir /var/www
chown plom:plom /var/www
cp "${config_tree_prefix}/setup_scripts/prepare_to_meet_server.sh" /home/plom/
chown plom:plom /home/plom/prepare_to_meet_server.sh
su -lc "./prepare_to_meet_server.sh ${old_server}" plom
read -p'Hit Enter when you are done.' ignore
su -lc "cd /var/repos && git clone --mirror ${old_server}:repos/website" plom
cp "${config_tree_prefix}/other_files/website_hook_post-receive" /var/repos/website.git/hooks/post-receive
su -lc 'cd /var/www && git clone /var/repos/website.git .' plom

# TODO:
# - commit git-daemon-export-ok directly into the public repos; rename
#   /home/plom/public_repos to /home/plom/repos

service nginx restart
